@@ -35,7 +35,7 @@ def default_pipe_logger(self):
     # https://stackoverflow.com/a/49500729
     lines = b""
     while True:
-        r = self.pipe.read()
+        r = self.pipe.read(32)
         lines += r
         while b"\n" in lines:
             line, lines = lines.split(b"\n", 1)
@@ -56,7 +56,7 @@ def pipe_logger_factory():
 
 
 class PipeFollower(threading.Thread):
-    def __init__(self, name, pname, pipe):
+    def __init__(self, name, pname, pipe, pipe_logger=None):
         threading.Thread.__init__(
             self, name=f"PipeFollower-{name}-{pname}", daemon=True
         )
@@ -64,7 +64,9 @@ class PipeFollower(threading.Thread):
         self.logger = logging.getLogger(
             ".".join([self.__class__.__name__, name, pname])
         )
-        self.pipe_logger = types.MethodType(pipe_logger_factory(), self)
+        if pipe_logger is None:
+            pipe_logger = pipe_logger_factory()
+        self.pipe_logger = types.MethodType(pipe_logger, self)
 
     def run(self):
         try:
